__all__ = [
    'WQB_API_URL',
    'URL_ALPHAS',
    'URL_ALPHAS_ALPHAID',
    'URL_ALPHAS_ALPHAID_CHECK',
    'URL_AUTHENTICATION',
    'URL_DATACATEGORIES',
    'URL_DATAFIELDS',
    'URL_DATAFIELDS_FIELDID',
    'URL_DATASETS',
    'URL_DATASETS_DATASETID',
    'URL_SIMULATIONS',
    'URL_USERS',
    'URL_USERS_SELF',
    'URL_USERS_SELF_ALPHAS',
]

HTTP_API_WORLDQUANTBRAIN_COM = 'http://api.worldquantbrain.com'
HTTPS_API_WORLDQUANTBRAIN_COM = 'https://api.worldquantbrain.com'

WQB_API_URL = HTTPS_API_WORLDQUANTBRAIN_COM
URL_ALPHAS = WQB_API_URL + '/alphas'
URL_ALPHAS_ALPHAID = URL_ALPHAS + '/{}'
URL_ALPHAS_ALPHAID_CHECK = URL_ALPHAS_ALPHAID + '/check'
# URL_ALPHAS_ALPHAID_SUBMIT = URL_ALPHAS_ALPHAID + '/submit'
URL_ALPHAS_ALPHAID_SUBMIT = 'http://api.worldquantbrain.com:443/alphas/{}/submit'
URL_AUTHENTICATION = WQB_API_URL + '/authentication'
URL_DATACATEGORIES = WQB_API_URL + '/data-categories'
URL_DATAFIELDS = WQB_API_URL + '/data-fields'
URL_DATAFIELDS_FIELDID = URL_DATAFIELDS + '/{}'
URL_DATASETS = WQB_API_URL + '/data-sets'
URL_DATASETS_DATASETID = URL_DATASETS + '/{}'
URL_OPERATORS = WQB_API_URL + '/operators'
URL_SIMULATIONS = WQB_API_URL + '/simulations'
URL_USERS = WQB_API_URL + '/users'
URL_USERS_SELF = URL_USERS + '/self'
URL_USERS_SELF_ALPHAS = URL_USERS_SELF + '/alphas'



from typing import Any

GET = 'GET'
POST = 'POST'
PUT = 'PUT'
PATCH = 'PATCH'
DELETE = 'DELETE'
HEAD = 'HEAD'
OPTIONS = 'OPTIONS'

LOCATION = 'Location'
RETRY_AFTER = 'Retry-After'

EQUITY = 'EQUITY'

Alpha = Any
MultiAlpha = Any

Region = Any
Delay = Any
Universe = Any
InstrumentType = Any
DataCategory = Any
FieldType = Any
DatasetsOrder = Any
FieldsOrder = Any
Status = Any
AlphaType = Any
AlphaCategory = Any
Language = Any
Color = Any
Neutralization = Any
UnitHandling = Any
NanHandling = Any
Pasteurization = Any
AlphasOrder = Any


class Null:
    pass


NULL = Null()

from . import auto_auth_session
from . import datetime_range
from . import filter_range
from . import wqb_session
from . import wqb_urls

__all__ = (
    auto_auth_session.__all__
    + datetime_range.__all__
    + filter_range.__all__
    + wqb_session.__all__
    + wqb_urls.__all__
)
del (
    auto_auth_session,
    datetime_range,
    filter_range,
    wqb_session,
    wqb_urls,
)

from .auto_auth_session import *
from .datetime_range import *
from .filter_range import *
from .wqb_session import *
from .wqb_urls import *
